# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class SubmissionBatch(EventTypeAbstractModel):

    Meta: "SubmissionBatchMeta" = Field(...)
    Transactions: List["SubmissionBatchTransaction"] = Field(None)


class SubmissionBatchMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["SubmissionBatchMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["SubmissionBatchMetaLog"] = Field(None)
    Message: "SubmissionBatchMetaMessage" = Field(None)
    Source: "SubmissionBatchMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "SubmissionBatchMetaTransmission" = Field(None)


class SubmissionBatchMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class SubmissionBatchMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class SubmissionBatchMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class SubmissionBatchMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class SubmissionBatchMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class SubmissionBatchTransaction(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Receiver: "SubmissionBatchTransactionReceiver" = Field(None)
    Submissions: List["SubmissionBatchTransactionSubmission"] = Field(None)
    Submitter: "SubmissionBatchTransactionSubmitter" = Field(None)
    Type: Union[str, None] = Field(None)


class SubmissionBatchTransactionReceiver(RedoxAbstractModel):

    Address: "SubmissionBatchTransactionReceiverAddress" = Field(None)
    EmailAddress: Union[str, None] = Field(None)
    Identifiers: List["SubmissionBatchTransactionReceiverIdentifier"] = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: "SubmissionBatchTransactionReceiverPhoneNumber" = Field(None)


class SubmissionBatchTransactionReceiverAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class SubmissionBatchTransactionReceiverIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class SubmissionBatchTransactionReceiverPhoneNumber(RedoxAbstractModel):

    Fax: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmission(RedoxAbstractModel):

    BillingProvider: "SubmissionBatchTransactionSubmissionBillingProvider" = Field(None)
    Subscribers: List["SubmissionBatchTransactionSubmissionSubscriber"] = Field(None)


class SubmissionBatchTransactionSubmissionBillingProvider(RedoxAbstractModel):

    Address: "SubmissionBatchTransactionSubmissionBillingProviderAddress" = Field(None)
    EmailAddress: Union[str, None] = Field(None)
    Identifiers: List[
        "SubmissionBatchTransactionSubmissionBillingProviderIdentifier"
    ] = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: "SubmissionBatchTransactionSubmissionBillingProviderPhoneNumber" = (
        Field(None)
    )
    Specialty: "SubmissionBatchTransactionSubmissionBillingProviderSpecialty" = Field(
        None
    )


class SubmissionBatchTransactionSubmissionBillingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionBillingProviderIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionBillingProviderPhoneNumber(
    RedoxAbstractModel
):

    Fax: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionBillingProviderSpecialty(RedoxAbstractModel):

    Description: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriber(RedoxAbstractModel):

    Demographics: "SubmissionBatchTransactionSubmissionSubscriberDemographics" = Field(
        None
    )
    Identifiers: List[
        "SubmissionBatchTransactionSubmissionSubscriberIdentifier"
    ] = Field(None)
    Insurance: "SubmissionBatchTransactionSubmissionSubscriberInsurance" = Field(None)
    OrganizationName: Union[str, None] = Field(None)
    Patients: List["SubmissionBatchTransactionSubmissionSubscriberPatient"] = Field(
        None
    )
    ResponsibilityLevel: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberDemographics(RedoxAbstractModel):

    Address: "SubmissionBatchTransactionSubmissionSubscriberDemographicsAddress" = (
        Field(None)
    )
    DOB: Union[str, None] = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "SubmissionBatchTransactionSubmissionSubscriberDemographicsPhoneNumber" = Field(
        None
    )
    Sex: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberDemographicsAddress(
    RedoxAbstractModel
):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberDemographicsPhoneNumber(
    RedoxAbstractModel
):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberInsurance(RedoxAbstractModel):

    AgreementType: Union[str, None] = Field(None)
    Company: "SubmissionBatchTransactionSubmissionSubscriberInsuranceCompany" = Field(
        None
    )
    CoverageType: Union[str, None] = Field(None)
    EffectiveDate: Union[str, None] = Field(None)
    ExpirationDate: Union[str, None] = Field(None)
    GroupName: Union[str, None] = Field(None)
    GroupNumber: Union[str, None] = Field(None)
    MemberNumber: Union[str, None] = Field(None)
    Plan: "SubmissionBatchTransactionSubmissionSubscriberInsurancePlan" = Field(None)
    PolicyNumber: Union[str, None] = Field(None)
    Priority: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberInsuranceCompany(
    RedoxAbstractModel
):

    Address: "SubmissionBatchTransactionSubmissionSubscriberInsuranceCompanyAddress" = (
        Field(None)
    )
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberInsuranceCompanyAddress(
    RedoxAbstractModel
):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberInsurancePlan(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatient(RedoxAbstractModel):

    Claims: List["SubmissionBatchTransactionSubmissionSubscriberPatientClaim"] = Field(
        None
    )
    Demographics: "SubmissionBatchTransactionSubmissionSubscriberPatientDemographics" = Field(
        None
    )
    Identifiers: List[
        "SubmissionBatchTransactionSubmissionSubscriberPatientIdentifier"
    ] = Field(None)
    Notes: List[str] = Field(None)
    RelationToSubscriber: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientClaim(RedoxAbstractModel):

    AdditionalDates: List[
        "SubmissionBatchTransactionSubmissionSubscriberPatientClaimAdditionalDate"
    ] = Field(None)
    BenefitsAssignmentCode: Union[bool, None] = Field(None)
    CopayAmount: Union[str, None] = Field(None)
    Diagnoses: List[
        "SubmissionBatchTransactionSubmissionSubscriberPatientClaimDiagnosis"
    ] = Field(None)
    DiagnosisRelatedGroup: Union[str, None] = Field(None)
    IsProviderSignatureOnFile: Union[bool, None] = Field(None)
    IsReleaseOfInformationOnFile: Union[bool, None] = Field(None)
    ProviderAcceptanceCode: Union[str, None] = Field(None)
    Providers: List[
        "SubmissionBatchTransactionSubmissionSubscriberPatientClaimProvider"
    ] = Field(None)
    ReferenceNumbers: List[
        "SubmissionBatchTransactionSubmissionSubscriberPatientClaimReferenceNumber"
    ] = Field(None)
    Services: List[
        "SubmissionBatchTransactionSubmissionSubscriberPatientClaimService"
    ] = Field(None)
    SubmissionNumber: Union[str, None] = Field(None)
    TotalAmount: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)
    Visit: "SubmissionBatchTransactionSubmissionSubscriberPatientClaimVisit" = Field(
        None
    )


class SubmissionBatchTransactionSubmissionSubscriberPatientClaimAdditionalDate(
    RedoxAbstractModel
):

    DateTime: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientClaimDiagnosis(
    RedoxAbstractModel
):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientClaimProvider(
    RedoxAbstractModel
):

    Address: "SubmissionBatchTransactionSubmissionSubscriberPatientClaimProviderAddress" = Field(
        None
    )
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "SubmissionBatchTransactionSubmissionSubscriberPatientClaimProviderLocation" = Field(
        None
    )
    PhoneNumber: "SubmissionBatchTransactionSubmissionSubscriberPatientClaimProviderPhoneNumber" = Field(
        None
    )
    Role: Union[str, None] = Field(None)
    Specialty: "SubmissionBatchTransactionSubmissionSubscriberPatientClaimProviderSpecialty" = Field(
        None
    )


class SubmissionBatchTransactionSubmissionSubscriberPatientClaimProviderAddress(
    RedoxAbstractModel
):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientClaimProviderLocation(
    RedoxAbstractModel
):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientClaimProviderPhoneNumber(
    RedoxAbstractModel
):

    Office: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientClaimProviderSpecialty(
    RedoxAbstractModel
):

    Description: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientClaimReferenceNumber(
    RedoxAbstractModel
):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientClaimService(
    RedoxAbstractModel
):

    Amount: Union[str, None] = Field(None)
    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)
    Diagnoses: List[
        "SubmissionBatchTransactionSubmissionSubscriberPatientClaimServiceDiagnosis"
    ] = Field(None)
    Drug: "SubmissionBatchTransactionSubmissionSubscriberPatientClaimServiceDrug" = (
        Field(None)
    )
    EndDateTime: Union[str, None] = Field(None)
    IsEmergency: Union[bool, None] = Field(None)
    Modifiers: List[str] = Field(None)
    Notes: Union[str, None] = Field(None)
    Quantity: "SubmissionBatchTransactionSubmissionSubscriberPatientClaimServiceQuantity" = Field(
        None
    )
    ReferenceNumbers: List[
        "SubmissionBatchTransactionSubmissionSubscriberPatientClaimServiceReferenceNumber"
    ] = Field(None)
    RevenueCode: Union[str, None] = Field(None)
    StartDateTime: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientClaimServiceDiagnosis(
    RedoxAbstractModel
):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientClaimServiceDrug(
    RedoxAbstractModel
):

    NDC: Union[str, None] = Field(None)
    PrescriptionID: Union[str, None] = Field(None)
    Quantity: "SubmissionBatchTransactionSubmissionSubscriberPatientClaimServiceDrugQuantity" = Field(
        None
    )


class SubmissionBatchTransactionSubmissionSubscriberPatientClaimServiceDrugQuantity(
    RedoxAbstractModel
):

    Units: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientClaimServiceQuantity(
    RedoxAbstractModel
):

    Units: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientClaimServiceReferenceNumber(
    RedoxAbstractModel
):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientClaimVisit(
    RedoxAbstractModel
):

    DateTime: Union[str, None] = Field(None)
    DischargeDateTime: Union[str, None] = Field(None)
    Location: "SubmissionBatchTransactionSubmissionSubscriberPatientClaimVisitLocation" = Field(
        None
    )
    PreviousLocation: "SubmissionBatchTransactionSubmissionSubscriberPatientClaimVisitPreviousLocation" = Field(
        None
    )
    Type: Union[str, None] = Field(None)
    VisitNumber: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientClaimVisitLocation(
    RedoxAbstractModel
):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientClaimVisitPreviousLocation(
    RedoxAbstractModel
):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientDemographics(
    RedoxAbstractModel
):

    Address: "SubmissionBatchTransactionSubmissionSubscriberPatientDemographicsAddress" = Field(
        None
    )
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "SubmissionBatchTransactionSubmissionSubscriberPatientDemographicsPhoneNumber" = Field(
        None
    )
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientDemographicsAddress(
    RedoxAbstractModel
):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientDemographicsPhoneNumber(
    RedoxAbstractModel
):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmissionSubscriberPatientIdentifier(
    RedoxAbstractModel
):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmitter(RedoxAbstractModel):

    Address: "SubmissionBatchTransactionSubmitterAddress" = Field(None)
    EmailAddress: Union[str, None] = Field(None)
    Identifiers: List["SubmissionBatchTransactionSubmitterIdentifier"] = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: "SubmissionBatchTransactionSubmitterPhoneNumber" = Field(None)


class SubmissionBatchTransactionSubmitterAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmitterIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class SubmissionBatchTransactionSubmitterPhoneNumber(RedoxAbstractModel):

    Fax: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


SubmissionBatch.update_forward_refs()
SubmissionBatchMeta.update_forward_refs()
SubmissionBatchTransaction.update_forward_refs()
SubmissionBatchTransactionReceiver.update_forward_refs()
SubmissionBatchTransactionSubmission.update_forward_refs()
SubmissionBatchTransactionSubmissionBillingProvider.update_forward_refs()
SubmissionBatchTransactionSubmissionSubscriber.update_forward_refs()
SubmissionBatchTransactionSubmissionSubscriberDemographics.update_forward_refs()
SubmissionBatchTransactionSubmissionSubscriberInsurance.update_forward_refs()
SubmissionBatchTransactionSubmissionSubscriberInsuranceCompany.update_forward_refs()
SubmissionBatchTransactionSubmissionSubscriberPatient.update_forward_refs()
SubmissionBatchTransactionSubmissionSubscriberPatientClaim.update_forward_refs()
SubmissionBatchTransactionSubmissionSubscriberPatientClaimProvider.update_forward_refs()
SubmissionBatchTransactionSubmissionSubscriberPatientClaimService.update_forward_refs()
SubmissionBatchTransactionSubmissionSubscriberPatientClaimServiceDrug.update_forward_refs()
SubmissionBatchTransactionSubmissionSubscriberPatientClaimVisit.update_forward_refs()
SubmissionBatchTransactionSubmissionSubscriberPatientDemographics.update_forward_refs()
SubmissionBatchTransactionSubmitter.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class LocationQuery(EventTypeAbstractModel):

    Meta: "LocationQueryMeta" = Field(...)
    Patient: "LocationQueryPatient" = Field(...)


class LocationQueryMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["LocationQueryMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["LocationQueryMetaLog"] = Field(None)
    Message: "LocationQueryMetaMessage" = Field(None)
    Source: "LocationQueryMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "LocationQueryMetaTransmission" = Field(None)


class LocationQueryMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class LocationQueryMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class LocationQueryMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class LocationQueryMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class LocationQueryMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class LocationQueryPatient(RedoxAbstractModel):

    Identifiers: List["LocationQueryPatientIdentifier"] = Field(...)


class LocationQueryPatientIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


LocationQuery.update_forward_refs()
LocationQueryMeta.update_forward_refs()
LocationQueryPatient.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class Update(EventTypeAbstractModel):

    Meta: "UpdateMeta" = Field(...)
    Order: "UpdateOrder" = Field(...)
    Patient: "UpdatePatient" = Field(...)
    Visit: "UpdateVisit" = Field(None)


class UpdateMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["UpdateMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["UpdateMetaLog"] = Field(None)
    Message: "UpdateMetaMessage" = Field(None)
    Source: "UpdateMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "UpdateMetaTransmission" = Field(None)


class UpdateMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class UpdateMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class UpdateMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class UpdateMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class UpdateMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class UpdateOrder(RedoxAbstractModel):

    ApplicationOrderID: Union[str, None] = Field(None)
    ClinicalInfo: List["UpdateOrderClinicalInfo"] = Field(None)
    CollectionDateTime: Union[str, None] = Field(None)
    Comments: Union[str, None] = Field(None)
    Diagnoses: List["UpdateOrderDiagnosis"] = Field(None)
    Expiration: Union[str, None] = Field(None)
    ID: str = Field(...)
    Notes: List[str] = Field(None)
    OrderingFacility: "UpdateOrderOrderingFacility" = Field(None)
    Priority: Union[str, None] = Field(None)
    Procedure: "UpdateOrderProcedure" = Field(None)
    Provider: "UpdateOrderProvider" = Field(None)
    ResultCopyProviders: List["UpdateOrderResultCopyProvider"] = Field(None)
    Specimen: "UpdateOrderSpecimen" = Field(None)
    Status: Union[str, None] = Field(None)
    TransactionDateTime: Union[str, None] = Field(None)


class UpdateOrderClinicalInfo(RedoxAbstractModel):

    Abbreviation: Union[str, None] = Field(None)
    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)
    Notes: List[str] = Field(None)
    Units: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class UpdateOrderDiagnosis(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    DocumentedDateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class UpdateOrderOrderingFacility(RedoxAbstractModel):

    Address: "UpdateOrderOrderingFacilityAddress" = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: Union[str, None] = Field(None)


class UpdateOrderOrderingFacilityAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdateOrderProcedure(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class UpdateOrderProvider(RedoxAbstractModel):

    Address: "UpdateOrderProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "UpdateOrderProviderLocation" = Field(None)
    NPI: Union[str, None] = Field(None)
    PhoneNumber: "UpdateOrderProviderPhoneNumber" = Field(None)


class UpdateOrderProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdateOrderProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class UpdateOrderProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class UpdateOrderResultCopyProvider(RedoxAbstractModel):

    Address: "UpdateOrderResultCopyProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "UpdateOrderResultCopyProviderLocation" = Field(None)
    PhoneNumber: "UpdateOrderResultCopyProviderPhoneNumber" = Field(None)


class UpdateOrderResultCopyProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdateOrderResultCopyProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class UpdateOrderResultCopyProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class UpdateOrderSpecimen(RedoxAbstractModel):

    BodySite: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    Source: Union[str, None] = Field(None)


class UpdatePatient(RedoxAbstractModel):

    Demographics: "UpdatePatientDemographics" = Field(None)
    Identifiers: List["UpdatePatientIdentifier"] = Field(...)
    Notes: List[str] = Field(None)


class UpdatePatientDemographics(RedoxAbstractModel):

    Address: "UpdatePatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "UpdatePatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class UpdatePatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdatePatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class UpdatePatientIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


class UpdateVisit(RedoxAbstractModel):

    AccountNumber: Union[str, None] = Field(None)
    AttendingProvider: "UpdateVisitAttendingProvider" = Field(None)
    ConsultingProvider: "UpdateVisitConsultingProvider" = Field(None)
    Guarantor: "UpdateVisitGuarantor" = Field(None)
    Insurances: List["UpdateVisitInsurance"] = Field(None)
    Location: "UpdateVisitLocation" = Field(None)
    PatientClass: Union[str, None] = Field(None)
    ReferringProvider: "UpdateVisitReferringProvider" = Field(None)
    VisitDateTime: Union[str, None] = Field(None)
    VisitNumber: Union[str, None] = Field(None)


class UpdateVisitAttendingProvider(RedoxAbstractModel):

    Address: "UpdateVisitAttendingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "UpdateVisitAttendingProviderLocation" = Field(None)
    PhoneNumber: "UpdateVisitAttendingProviderPhoneNumber" = Field(None)


class UpdateVisitAttendingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdateVisitAttendingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class UpdateVisitAttendingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class UpdateVisitConsultingProvider(RedoxAbstractModel):

    Address: "UpdateVisitConsultingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "UpdateVisitConsultingProviderLocation" = Field(None)
    PhoneNumber: "UpdateVisitConsultingProviderPhoneNumber" = Field(None)


class UpdateVisitConsultingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdateVisitConsultingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class UpdateVisitConsultingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class UpdateVisitGuarantor(RedoxAbstractModel):

    Address: "UpdateVisitGuarantorAddress" = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    Employer: "UpdateVisitGuarantorEmployer" = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    Number: Union[str, None] = Field(None)
    PhoneNumber: "UpdateVisitGuarantorPhoneNumber" = Field(None)
    RelationToPatient: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    Spouse: "UpdateVisitGuarantorSpouse" = Field(None)
    SSN: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class UpdateVisitGuarantorAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdateVisitGuarantorEmployer(RedoxAbstractModel):

    Address: "UpdateVisitGuarantorEmployerAddress" = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: Union[str, None] = Field(None)


class UpdateVisitGuarantorEmployerAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdateVisitGuarantorPhoneNumber(RedoxAbstractModel):

    Business: Union[str, None] = Field(None)
    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)


class UpdateVisitGuarantorSpouse(RedoxAbstractModel):

    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)


class UpdateVisitInsurance(RedoxAbstractModel):

    AgreementType: Union[str, None] = Field(None)
    Company: "UpdateVisitInsuranceCompany" = Field(None)
    CoverageType: Union[str, None] = Field(None)
    EffectiveDate: Union[str, None] = Field(None)
    ExpirationDate: Union[str, None] = Field(None)
    GroupName: Union[str, None] = Field(None)
    GroupNumber: Union[str, None] = Field(None)
    Insured: "UpdateVisitInsuranceInsured" = Field(None)
    MemberNumber: Union[str, None] = Field(None)
    Plan: "UpdateVisitInsurancePlan" = Field(None)
    PolicyNumber: Union[str, None] = Field(None)
    Priority: Union[str, None] = Field(None)


class UpdateVisitInsuranceCompany(RedoxAbstractModel):

    Address: "UpdateVisitInsuranceCompanyAddress" = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: Union[str, None] = Field(None)


class UpdateVisitInsuranceCompanyAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdateVisitInsuranceInsured(RedoxAbstractModel):

    Address: "UpdateVisitInsuranceInsuredAddress" = Field(None)
    DOB: Union[str, None] = Field(None)
    FirstName: Union[str, None] = Field(None)
    Identifiers: List["UpdateVisitInsuranceInsuredIdentifier"] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    Relationship: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class UpdateVisitInsuranceInsuredAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdateVisitInsuranceInsuredIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class UpdateVisitInsurancePlan(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class UpdateVisitLocation(RedoxAbstractModel):

    Bed: Union[str, None] = Field(None)
    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class UpdateVisitReferringProvider(RedoxAbstractModel):

    Address: "UpdateVisitReferringProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "UpdateVisitReferringProviderLocation" = Field(None)
    PhoneNumber: "UpdateVisitReferringProviderPhoneNumber" = Field(None)


class UpdateVisitReferringProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdateVisitReferringProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class UpdateVisitReferringProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


Update.update_forward_refs()
UpdateMeta.update_forward_refs()
UpdateOrder.update_forward_refs()
UpdateOrderOrderingFacility.update_forward_refs()
UpdateOrderProvider.update_forward_refs()
UpdateOrderResultCopyProvider.update_forward_refs()
UpdatePatient.update_forward_refs()
UpdatePatientDemographics.update_forward_refs()
UpdateVisit.update_forward_refs()
UpdateVisitAttendingProvider.update_forward_refs()
UpdateVisitConsultingProvider.update_forward_refs()
UpdateVisitGuarantor.update_forward_refs()
UpdateVisitGuarantorEmployer.update_forward_refs()
UpdateVisitInsurance.update_forward_refs()
UpdateVisitInsuranceCompany.update_forward_refs()
UpdateVisitInsuranceInsured.update_forward_refs()
UpdateVisitReferringProvider.update_forward_refs()



# -*- coding: utf-8 -*-


class Number(float):
    """A float with extra awesome actions!

    Without this type defined and available for Redox fields, there are some
    edge cases where testing equality of values can yield some unexpected
    failures, such as 15.0 != "15". Overloading the parent methods for
    ``str`` and ``repr`` corrects this problem.
    """

    def __repr__(self):
        return int(self).__repr__() if self == int(self) else super().__repr__()

    def __str__(self):
        return int(self).__str__() if self == int(self) else super().__str__()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class QueryResponse(EventTypeAbstractModel):

    Media: List["QueryResponseMedium"] = Field(None)
    Meta: "QueryResponseMeta" = Field(...)


class QueryResponseMedium(RedoxAbstractModel):

    CreationDateTime: Union[str, None] = Field(None)
    DocumentDescription: Union[str, None] = Field(None)
    DocumentID: Union[str, None] = Field(None)
    DocumentType: Union[str, None] = Field(None)
    FileContents: Union[str, None] = Field(None)
    FileName: Union[str, None] = Field(None)
    FileType: Union[str, None] = Field(None)
    Patient: "QueryResponseMediumPatient" = Field(None)
    ServiceDateTime: Union[str, None] = Field(None)
    Visit: "QueryResponseMediumVisit" = Field(None)


class QueryResponseMediumPatient(RedoxAbstractModel):

    Identifiers: List["QueryResponseMediumPatientIdentifier"] = Field(None)


class QueryResponseMediumPatientIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class QueryResponseMediumVisit(RedoxAbstractModel):

    VisitNumber: Union[str, None] = Field(None)


class QueryResponseMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["QueryResponseMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["QueryResponseMetaLog"] = Field(None)
    Message: "QueryResponseMetaMessage" = Field(None)
    Source: "QueryResponseMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "QueryResponseMetaTransmission" = Field(None)


class QueryResponseMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class QueryResponseMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class QueryResponseMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class QueryResponseMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class QueryResponseMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


QueryResponse.update_forward_refs()
QueryResponseMedium.update_forward_refs()
QueryResponseMediumPatient.update_forward_refs()
QueryResponseMeta.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class Response(EventTypeAbstractModel):

    Advisories: List["ResponseAdvisory"] = Field(...)
    Meta: "ResponseMeta" = Field(...)


class ResponseAdvisory(RedoxAbstractModel):

    AdditionalInfo: List["ResponseAdvisoryAdditionalInfo"] = Field(None)
    AdditionalUnsignedOrders: List["ResponseAdvisoryAdditionalUnsignedOrder"] = Field(
        None
    )
    Description: Union[str, None] = Field(None)
    Errors: List["ResponseAdvisoryError"] = Field(None)
    Notes: List["ResponseAdvisoryNote"] = Field(None)
    RemovableUnsignedOrders: List["ResponseAdvisoryRemovableUnsignedOrder"] = Field(
        None
    )
    Session: str = Field(...)
    ShowAlert: Union[bool, None] = Field(None)


class ResponseAdvisoryAdditionalInfo(RedoxAbstractModel):

    DecisionSupport: "ResponseAdvisoryAdditionalInfoDecisionSupport" = Field(None)
    Link: Union[str, None] = Field(None)


class ResponseAdvisoryAdditionalInfoDecisionSupport(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class ResponseAdvisoryAdditionalUnsignedOrder(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Questions: List["ResponseAdvisoryAdditionalUnsignedOrderQuestion"] = Field(None)
    Title: Union[str, None] = Field(None)


class ResponseAdvisoryAdditionalUnsignedOrderQuestion(RedoxAbstractModel):

    Answers: List["ResponseAdvisoryAdditionalUnsignedOrderQuestionAnswer"] = Field(None)
    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class ResponseAdvisoryAdditionalUnsignedOrderQuestionAnswer(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Comment: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class ResponseAdvisoryError(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class ResponseAdvisoryNote(RedoxAbstractModel):

    Display: Union[str, None] = Field(None)
    Text: Union[str, None] = Field(None)


class ResponseAdvisoryRemovableUnsignedOrder(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Title: Union[str, None] = Field(None)


class ResponseMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["ResponseMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["ResponseMetaLog"] = Field(None)
    Message: "ResponseMetaMessage" = Field(None)
    Source: "ResponseMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "ResponseMetaTransmission" = Field(None)


class ResponseMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class ResponseMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class ResponseMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class ResponseMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class ResponseMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


Response.update_forward_refs()
ResponseAdvisory.update_forward_refs()
ResponseAdvisoryAdditionalInfo.update_forward_refs()
ResponseAdvisoryAdditionalUnsignedOrder.update_forward_refs()
ResponseAdvisoryAdditionalUnsignedOrderQuestion.update_forward_refs()
ResponseMeta.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class Update(EventTypeAbstractModel):

    Meta: "UpdateMeta" = Field(...)
    Providers: List["UpdateProvider"] = Field(...)


class UpdateMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["UpdateMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["UpdateMetaLog"] = Field(None)
    Message: "UpdateMetaMessage" = Field(None)
    Source: "UpdateMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "UpdateMetaTransmission" = Field(None)


class UpdateMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class UpdateMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class UpdateMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class UpdateMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class UpdateMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class UpdateProvider(RedoxAbstractModel):

    Demographics: "UpdateProviderDemographics" = Field(None)
    Identifiers: List["UpdateProviderIdentifier"] = Field(...)
    IsActive: bool = Field(...)
    Qualifications: List["UpdateProviderQualification"] = Field(None)
    Roles: List["UpdateProviderRole"] = Field(None)


class UpdateProviderDemographics(RedoxAbstractModel):

    Addresses: List["UpdateProviderDemographicsAddress"] = Field(None)
    Credentials: List[str] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    Languages: List[str] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "UpdateProviderDemographicsPhoneNumber" = Field(None)
    Sex: Union[str, None] = Field(None)


class UpdateProviderDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    Use: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdateProviderDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class UpdateProviderIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: Union[str, None] = Field(None)


class UpdateProviderQualification(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    Identifiers: List["UpdateProviderQualificationIdentifier"] = Field(None)
    StartDate: Union[str, None] = Field(None)


class UpdateProviderQualificationIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class UpdateProviderRole(RedoxAbstractModel):

    Availability: List["UpdateProviderRoleAvailability"] = Field(None)
    Identifiers: List["UpdateProviderRoleIdentifier"] = Field(None)
    Locations: List["UpdateProviderRoleLocation"] = Field(None)
    Organization: "UpdateProviderRoleOrganization" = Field(None)
    Services: List["UpdateProviderRoleService"] = Field(None)
    Specialties: List["UpdateProviderRoleSpecialty"] = Field(None)


class UpdateProviderRoleAvailability(RedoxAbstractModel):

    AvailableEndTime: Union[str, None] = Field(None)
    AvailableStartTime: Union[str, None] = Field(None)
    Days: List[str] = Field(None)


class UpdateProviderRoleIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class UpdateProviderRoleLocation(RedoxAbstractModel):

    Address: "UpdateProviderRoleLocationAddress" = Field(None)
    Description: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    Identifiers: List["UpdateProviderRoleLocationIdentifier"] = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: "UpdateProviderRoleLocationPhoneNumber" = Field(None)
    Status: Union[str, None] = Field(None)


class UpdateProviderRoleLocationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdateProviderRoleLocationIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class UpdateProviderRoleLocationPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class UpdateProviderRoleOrganization(RedoxAbstractModel):

    Address: "UpdateProviderRoleOrganizationAddress" = Field(None)
    Identifiers: List["UpdateProviderRoleOrganizationIdentifier"] = Field(None)
    IsActive: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class UpdateProviderRoleOrganizationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class UpdateProviderRoleOrganizationIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class UpdateProviderRoleService(RedoxAbstractModel):

    Description: Union[str, None] = Field(None)
    Identifiers: List["UpdateProviderRoleServiceIdentifier"] = Field(None)
    PhoneNumber: "UpdateProviderRoleServicePhoneNumber" = Field(None)
    Type: Union[str, None] = Field(None)


class UpdateProviderRoleServiceIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class UpdateProviderRoleServicePhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class UpdateProviderRoleSpecialty(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


Update.update_forward_refs()
UpdateMeta.update_forward_refs()
UpdateProvider.update_forward_refs()
UpdateProviderDemographics.update_forward_refs()
UpdateProviderQualification.update_forward_refs()
UpdateProviderRole.update_forward_refs()
UpdateProviderRoleLocation.update_forward_refs()
UpdateProviderRoleOrganization.update_forward_refs()
UpdateProviderRoleService.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from pyredox import provider
from ..abstract_base import GenericRedoxAbstractModel
from . import types as generic


class _Provider(GenericRedoxAbstractModel):
    _redox_module = provider


class Activate(_Provider):

    Meta: generic.Meta = Field(...)
    Providers: List[generic.Provider] = Field(...)


class Deactivate(_Provider):

    Meta: generic.Meta = Field(...)
    Providers: List[generic.Provider] = Field(...)


class New(_Provider):

    Meta: generic.Meta = Field(...)
    Providers: List[generic.Provider] = Field(...)


class ProviderQuery(_Provider):

    Meta: generic.Meta = Field(...)
    Provider: generic.Provider = Field(None)


class ProviderQueryResponse(_Provider):

    Meta: generic.Meta = Field(...)
    Providers: List[generic.Provider] = Field(...)


class Update(_Provider):

    Meta: generic.Meta = Field(...)
    Providers: List[generic.Provider] = Field(...)



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class Request(EventTypeAbstractModel):

    AuthorizingProvider: "RequestAuthorizingProvider" = Field(None)
    Meta: "RequestMeta" = Field(...)
    OrderingProvider: "RequestOrderingProvider" = Field(None)
    Patient: "RequestPatient" = Field(...)
    Session: "RequestSession" = Field(None)
    UnsignedMedicationOrders: List["RequestUnsignedMedicationOrder"] = Field(...)
    UnsignedProcedureOrders: List["RequestUnsignedProcedureOrder"] = Field(...)


class RequestAuthorizingProvider(RedoxAbstractModel):

    Address: "RequestAuthorizingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "RequestAuthorizingProviderLocation" = Field(None)
    PhoneNumber: "RequestAuthorizingProviderPhoneNumber" = Field(None)


class RequestAuthorizingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class RequestAuthorizingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class RequestAuthorizingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class RequestMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["RequestMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["RequestMetaLog"] = Field(None)
    Message: "RequestMetaMessage" = Field(None)
    Source: "RequestMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "RequestMetaTransmission" = Field(None)


class RequestMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class RequestMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class RequestMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class RequestMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class RequestMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class RequestOrderingProvider(RedoxAbstractModel):

    Address: "RequestOrderingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "RequestOrderingProviderLocation" = Field(None)
    PhoneNumber: "RequestOrderingProviderPhoneNumber" = Field(None)


class RequestOrderingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class RequestOrderingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class RequestOrderingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class RequestPatient(RedoxAbstractModel):

    Demographics: "RequestPatientDemographics" = Field(None)
    Identifiers: List["RequestPatientIdentifier"] = Field(...)
    Notes: List[str] = Field(None)


class RequestPatientDemographics(RedoxAbstractModel):

    Address: "RequestPatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "RequestPatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class RequestPatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class RequestPatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class RequestPatientIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


class RequestSession(RedoxAbstractModel):

    Questions: List["RequestSessionQuestion"] = Field(None)


class RequestSessionQuestion(RedoxAbstractModel):

    Answer: "RequestSessionQuestionAnswer" = Field(None)
    Question: "RequestSessionQuestionQuestion" = Field(None)


class RequestSessionQuestionAnswer(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class RequestSessionQuestionQuestion(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class RequestUnsignedMedicationOrder(RedoxAbstractModel):

    Dose: "RequestUnsignedMedicationOrderDose" = Field(None)
    EndDate: Union[str, None] = Field(None)
    Frequency: "RequestUnsignedMedicationOrderFrequency" = Field(None)
    Identifiers: List["RequestUnsignedMedicationOrderIdentifier"] = Field(...)
    MixtureComponents: List["RequestUnsignedMedicationOrderMixtureComponent"] = Field(
        None
    )
    MixtureType: Union[str, None] = Field(None)
    Mode: Union[str, None] = Field(None)
    Notes: List[str] = Field(None)
    Priority: Union[str, None] = Field(None)
    Product: "RequestUnsignedMedicationOrderProduct" = Field(None)
    Questions: List["RequestUnsignedMedicationOrderQuestion"] = Field(None)
    Route: Union[None] = Field(None)
    StartDate: Union[str, None] = Field(None)


class RequestUnsignedMedicationOrderDose(RedoxAbstractModel):

    Quantity: Union[Number, None] = Field(None)
    Units: Union[str, None] = Field(None)


class RequestUnsignedMedicationOrderFrequency(RedoxAbstractModel):

    Period: Union[str, None] = Field(None)
    Unit: Union[str, None] = Field(None)


class RequestUnsignedMedicationOrderIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


class RequestUnsignedMedicationOrderMixtureComponent(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeType: Union[str, None] = Field(None)
    Dose: "RequestUnsignedMedicationOrderMixtureComponentDose" = Field(None)


class RequestUnsignedMedicationOrderMixtureComponentDose(RedoxAbstractModel):

    Quantity: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)


class RequestUnsignedMedicationOrderProduct(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class RequestUnsignedMedicationOrderQuestion(RedoxAbstractModel):

    Answer: "RequestUnsignedMedicationOrderQuestionAnswer" = Field(None)
    Question: "RequestUnsignedMedicationOrderQuestionQuestion" = Field(None)


class RequestUnsignedMedicationOrderQuestionAnswer(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class RequestUnsignedMedicationOrderQuestionQuestion(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class RequestUnsignedProcedureOrder(RedoxAbstractModel):

    BodySite: "RequestUnsignedProcedureOrderBodySite" = Field(None)
    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    Identifiers: List["RequestUnsignedProcedureOrderIdentifier"] = Field(...)
    Mode: Union[str, None] = Field(None)
    Notes: List[str] = Field(None)
    Questions: List["RequestUnsignedProcedureOrderQuestion"] = Field(None)
    ScheduledDate: Union[str, None] = Field(None)
    StartDate: Union[str, None] = Field(None)


class RequestUnsignedProcedureOrderBodySite(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class RequestUnsignedProcedureOrderIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: Number = Field(...)


class RequestUnsignedProcedureOrderQuestion(RedoxAbstractModel):

    Answer: "RequestUnsignedProcedureOrderQuestionAnswer" = Field(None)
    Question: "RequestUnsignedProcedureOrderQuestionQuestion" = Field(None)


class RequestUnsignedProcedureOrderQuestionAnswer(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class RequestUnsignedProcedureOrderQuestionQuestion(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


Request.update_forward_refs()
RequestAuthorizingProvider.update_forward_refs()
RequestMeta.update_forward_refs()
RequestOrderingProvider.update_forward_refs()
RequestPatient.update_forward_refs()
RequestPatientDemographics.update_forward_refs()
RequestSession.update_forward_refs()
RequestSessionQuestion.update_forward_refs()
RequestUnsignedMedicationOrder.update_forward_refs()
RequestUnsignedMedicationOrderMixtureComponent.update_forward_refs()
RequestUnsignedMedicationOrderQuestion.update_forward_refs()
RequestUnsignedProcedureOrder.update_forward_refs()
RequestUnsignedProcedureOrderQuestion.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from pyredox import claim
from ..abstract_base import GenericRedoxAbstractModel
from . import types as generic


class _Claim(GenericRedoxAbstractModel):
    _redox_module = claim


class Payment(_Claim):

    Meta: generic.Meta = Field(...)
    Payee: generic.Payee = Field(None)
    Payer: generic.Payer = Field(None)
    Payments: List[generic.Payment] = Field(...)
    Transaction: generic.Transaction = Field(None)


class PaymentBatch(_Claim):

    Meta: generic.Meta = Field(...)
    Transactions: List[generic.Transaction] = Field(None)


class Submission(_Claim):

    BillingProvider: generic.BillingProvider = Field(None)
    Claims: List[generic.Claim] = Field(None)
    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(None)
    Subscriber: generic.Subscriber = Field(None)
    Transaction: generic.Transaction = Field(None)


class SubmissionBatch(_Claim):

    Meta: generic.Meta = Field(...)
    Transactions: List[generic.Transaction] = Field(None)



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class Cancel(EventTypeAbstractModel):

    Meta: "CancelMeta" = Field(...)
    Patient: "CancelPatient" = Field(...)
    Referral: "CancelReferral" = Field(None)
    Visit: "CancelVisit" = Field(None)


class CancelMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["CancelMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["CancelMetaLog"] = Field(None)
    Message: "CancelMetaMessage" = Field(None)
    Source: "CancelMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "CancelMetaTransmission" = Field(None)


class CancelMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class CancelMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class CancelMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class CancelMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class CancelMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class CancelPatient(RedoxAbstractModel):

    Contacts: List["CancelPatientContact"] = Field(None)
    Demographics: "CancelPatientDemographics" = Field(None)
    Guarantor: "CancelPatientGuarantor" = Field(None)
    Identifiers: List["CancelPatientIdentifier"] = Field(...)
    Insurances: List["CancelPatientInsurance"] = Field(None)
    Notes: List[str] = Field(None)


class CancelPatientContact(RedoxAbstractModel):

    Address: "CancelPatientContactAddress" = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "CancelPatientContactPhoneNumber" = Field(None)
    RelationToPatient: Union[str, None] = Field(None)
    Roles: List[str] = Field(None)


class CancelPatientContactAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class CancelPatientContactPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class CancelPatientDemographics(RedoxAbstractModel):

    Address: "CancelPatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "CancelPatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class CancelPatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class CancelPatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class CancelPatientGuarantor(RedoxAbstractModel):

    Address: "CancelPatientGuarantorAddress" = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    Employer: "CancelPatientGuarantorEmployer" = Field(None)
    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    Number: Union[str, None] = Field(None)
    PhoneNumber: "CancelPatientGuarantorPhoneNumber" = Field(None)
    RelationToPatient: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    Spouse: "CancelPatientGuarantorSpouse" = Field(None)
    SSN: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class CancelPatientGuarantorAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class CancelPatientGuarantorEmployer(RedoxAbstractModel):

    Address: "CancelPatientGuarantorEmployerAddress" = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: Union[str, None] = Field(None)


class CancelPatientGuarantorEmployerAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class CancelPatientGuarantorPhoneNumber(RedoxAbstractModel):

    Business: Union[str, None] = Field(None)
    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)


class CancelPatientGuarantorSpouse(RedoxAbstractModel):

    FirstName: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)


class CancelPatientIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


class CancelPatientInsurance(RedoxAbstractModel):

    AgreementType: Union[str, None] = Field(None)
    Company: "CancelPatientInsuranceCompany" = Field(None)
    CoverageType: Union[str, None] = Field(None)
    EffectiveDate: Union[str, None] = Field(None)
    ExpirationDate: Union[str, None] = Field(None)
    GroupName: Union[str, None] = Field(None)
    GroupNumber: Union[str, None] = Field(None)
    Insured: "CancelPatientInsuranceInsured" = Field(None)
    MemberNumber: Union[str, None] = Field(None)
    Plan: "CancelPatientInsurancePlan" = Field(None)
    PolicyNumber: Union[str, None] = Field(None)
    Priority: Union[str, None] = Field(None)


class CancelPatientInsuranceCompany(RedoxAbstractModel):

    Address: "CancelPatientInsuranceCompanyAddress" = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: Union[str, None] = Field(None)


class CancelPatientInsuranceCompanyAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class CancelPatientInsuranceInsured(RedoxAbstractModel):

    Address: "CancelPatientInsuranceInsuredAddress" = Field(None)
    DOB: Union[str, None] = Field(None)
    FirstName: Union[str, None] = Field(None)
    Identifiers: List["CancelPatientInsuranceInsuredIdentifier"] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    Relationship: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class CancelPatientInsuranceInsuredAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class CancelPatientInsuranceInsuredIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class CancelPatientInsurancePlan(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class CancelReferral(RedoxAbstractModel):

    AlternateID: Union[str, None] = Field(None)
    Authorization: "CancelReferralAuthorization" = Field(None)
    Category: Union[str, None] = Field(None)
    DateTime: Union[str, None] = Field(None)
    DepartmentSpecialty: Union[str, None] = Field(None)
    Diagnoses: List["CancelReferralDiagnosis"] = Field(None)
    ExpirationDateTime: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Notes: List[str] = Field(None)
    Priority: Union[str, None] = Field(None)
    Procedures: List["CancelReferralProcedure"] = Field(None)
    ProcessDateTime: Union[str, None] = Field(None)
    Providers: List["CancelReferralProvider"] = Field(None)
    ProviderSpecialty: Union[str, None] = Field(None)
    Reason: Union[str, None] = Field(None)
    Status: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)
    Visit: "CancelReferralVisit" = Field(None)


class CancelReferralAuthorization(RedoxAbstractModel):

    AuthorizedTreatmentCount: Union[str, None] = Field(None)
    Company: "CancelReferralAuthorizationCompany" = Field(None)
    DateTime: Union[str, None] = Field(None)
    ExpirationDateTime: Union[str, None] = Field(None)
    Notes: List[str] = Field(None)
    Number: Union[str, None] = Field(None)
    Plan: "CancelReferralAuthorizationPlan" = Field(None)
    ReimbursementLimit: Union[str, None] = Field(None)
    RequestedTreatmentCount: Union[str, None] = Field(None)
    RequestedTreatmentUnits: Union[str, None] = Field(None)


class CancelReferralAuthorizationCompany(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class CancelReferralAuthorizationPlan(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class CancelReferralDiagnosis(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    DocumentedDateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Notes: List[str] = Field(None)
    Type: Union[str, None] = Field(None)


class CancelReferralProcedure(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)
    Modifiers: List[str] = Field(None)
    Notes: List[str] = Field(None)
    Quantity: Union[str, None] = Field(None)
    Units: Union[str, None] = Field(None)


class CancelReferralProvider(RedoxAbstractModel):

    Address: "CancelReferralProviderAddress" = Field(None)
    ContactInfo: Union[str, None] = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "CancelReferralProviderLocation" = Field(None)
    PhoneNumber: "CancelReferralProviderPhoneNumber" = Field(None)
    Type: Union[str, None] = Field(None)


class CancelReferralProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class CancelReferralProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class CancelReferralProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class CancelReferralVisit(RedoxAbstractModel):

    VisitNumber: Union[str, None] = Field(None)


class CancelVisit(RedoxAbstractModel):

    VisitNumber: Union[str, None] = Field(None)


Cancel.update_forward_refs()
CancelMeta.update_forward_refs()
CancelPatient.update_forward_refs()
CancelPatientContact.update_forward_refs()
CancelPatientDemographics.update_forward_refs()
CancelPatientGuarantor.update_forward_refs()
CancelPatientGuarantorEmployer.update_forward_refs()
CancelPatientInsurance.update_forward_refs()
CancelPatientInsuranceCompany.update_forward_refs()
CancelPatientInsuranceInsured.update_forward_refs()
CancelReferral.update_forward_refs()
CancelReferralAuthorization.update_forward_refs()
CancelReferralProvider.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class NoShow(EventTypeAbstractModel):

    AppointmentInfo: List["NoShowAppointmentInfo"] = Field(None)
    Meta: "NoShowMeta" = Field(...)
    Patient: "NoShowPatient" = Field(None)
    Visit: "NoShowVisit" = Field(...)


class NoShowAppointmentInfo(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)
    Value: Union[str, None] = Field(None)


class NoShowMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["NoShowMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["NoShowMetaLog"] = Field(None)
    Message: "NoShowMetaMessage" = Field(None)
    Source: "NoShowMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "NoShowMetaTransmission" = Field(None)


class NoShowMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class NoShowMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class NoShowMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class NoShowMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class NoShowMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class NoShowPatient(RedoxAbstractModel):

    Demographics: "NoShowPatientDemographics" = Field(None)
    Identifiers: List["NoShowPatientIdentifier"] = Field(None)
    Notes: List[str] = Field(None)


class NoShowPatientDemographics(RedoxAbstractModel):

    Address: "NoShowPatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "NoShowPatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class NoShowPatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class NoShowPatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class NoShowPatientIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class NoShowVisit(RedoxAbstractModel):

    AccountNumber: Union[str, None] = Field(None)
    AdditionalStaff: List["NoShowVisitAdditionalStaff"] = Field(None)
    AttendingProvider: "NoShowVisitAttendingProvider" = Field(None)
    ConsultingProvider: "NoShowVisitConsultingProvider" = Field(None)
    Diagnoses: List["NoShowVisitDiagnosis"] = Field(None)
    Duration: Union[Number, None] = Field(None)
    Equipment: List["NoShowVisitEquipment"] = Field(None)
    Instructions: List[str] = Field(None)
    Location: "NoShowVisitLocation" = Field(...)
    NoShowReason: Union[str, None] = Field(None)
    PatientClass: Union[str, None] = Field(None)
    Reason: Union[str, None] = Field(None)
    ReferringProvider: "NoShowVisitReferringProvider" = Field(None)
    Status: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)
    VisitDateTime: str = Field(...)
    VisitNumber: str = Field(...)
    VisitProvider: "NoShowVisitVisitProvider" = Field(None)


class NoShowVisitAdditionalStaff(RedoxAbstractModel):

    Address: "NoShowVisitAdditionalStaffAddress" = Field(None)
    Credentials: List[str] = Field(None)
    Duration: Union[Number, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "NoShowVisitAdditionalStaffLocation" = Field(None)
    PhoneNumber: "NoShowVisitAdditionalStaffPhoneNumber" = Field(None)
    Role: "NoShowVisitAdditionalStaffRole" = Field(None)
    StartDateTime: Union[str, None] = Field(None)


class NoShowVisitAdditionalStaffAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class NoShowVisitAdditionalStaffLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class NoShowVisitAdditionalStaffPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class NoShowVisitAdditionalStaffRole(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class NoShowVisitAttendingProvider(RedoxAbstractModel):

    Address: "NoShowVisitAttendingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "NoShowVisitAttendingProviderLocation" = Field(None)
    PhoneNumber: "NoShowVisitAttendingProviderPhoneNumber" = Field(None)


class NoShowVisitAttendingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class NoShowVisitAttendingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class NoShowVisitAttendingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class NoShowVisitConsultingProvider(RedoxAbstractModel):

    Address: "NoShowVisitConsultingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "NoShowVisitConsultingProviderLocation" = Field(None)
    PhoneNumber: "NoShowVisitConsultingProviderPhoneNumber" = Field(None)


class NoShowVisitConsultingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class NoShowVisitConsultingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class NoShowVisitConsultingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class NoShowVisitDiagnosis(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    DocumentedDateTime: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class NoShowVisitEquipment(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)
    Duration: Union[Number, None] = Field(None)
    StartDateTime: Union[str, None] = Field(None)


class NoShowVisitLocation(RedoxAbstractModel):

    Department: str = Field(...)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class NoShowVisitReferringProvider(RedoxAbstractModel):

    Address: "NoShowVisitReferringProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "NoShowVisitReferringProviderLocation" = Field(None)
    PhoneNumber: "NoShowVisitReferringProviderPhoneNumber" = Field(None)


class NoShowVisitReferringProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class NoShowVisitReferringProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class NoShowVisitReferringProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class NoShowVisitVisitProvider(RedoxAbstractModel):

    Address: "NoShowVisitVisitProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "NoShowVisitVisitProviderLocation" = Field(None)
    PhoneNumber: "NoShowVisitVisitProviderPhoneNumber" = Field(None)


class NoShowVisitVisitProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class NoShowVisitVisitProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class NoShowVisitVisitProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


NoShow.update_forward_refs()
NoShowMeta.update_forward_refs()
NoShowPatient.update_forward_refs()
NoShowPatientDemographics.update_forward_refs()
NoShowVisit.update_forward_refs()
NoShowVisitAdditionalStaff.update_forward_refs()
NoShowVisitAttendingProvider.update_forward_refs()
NoShowVisitConsultingProvider.update_forward_refs()
NoShowVisitReferringProvider.update_forward_refs()
NoShowVisitVisitProvider.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from pyredox import referral
from ..abstract_base import GenericRedoxAbstractModel
from . import types as generic


class _Referral(GenericRedoxAbstractModel):
    _redox_module = referral


class AuthResponse(_Referral):

    Authorization: generic.Authorization = Field(None)
    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)
    Referral: generic.Referral = Field(None)


class AuthReview(_Referral):

    Authorization: generic.Authorization = Field(None)
    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)
    Referral: generic.Referral = Field(None)


class Cancel(_Referral):

    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)
    Referral: generic.Referral = Field(None)
    Visit: generic.Visit = Field(None)


class Modify(_Referral):

    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)
    Referral: generic.Referral = Field(None)
    Visit: generic.Visit = Field(None)


class New(_Referral):

    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)
    Referral: generic.Referral = Field(None)
    Visit: generic.Visit = Field(None)


class Query(_Referral):

    Meta: generic.Meta = Field(...)
    Patient: generic.Patient = Field(...)


class QueryResponse(_Referral):

    Meta: generic.Meta = Field(...)
    Referrals: List[generic.Referral] = Field(None)



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class Administration(EventTypeAbstractModel):

    Administrations: List["AdministrationAdministration"] = Field(...)
    Meta: "AdministrationMeta" = Field(...)
    Patient: "AdministrationPatient" = Field(...)
    Visit: "AdministrationVisit" = Field(None)


class AdministrationAdministration(RedoxAbstractModel):

    AdministeringProvider: "AdministrationAdministrationAdministeringProvider" = Field(
        None
    )
    EndDate: Union[str, None] = Field(None)
    Medication: "AdministrationAdministrationMedication" = Field(...)
    OrderedBy: "AdministrationAdministrationOrderedBy" = Field(None)
    StartDate: Union[str, None] = Field(None)
    Status: str = Field(...)
    VerifiedBy: "AdministrationAdministrationVerifiedBy" = Field(None)


class AdministrationAdministrationAdministeringProvider(RedoxAbstractModel):

    Address: "AdministrationAdministrationAdministeringProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "AdministrationAdministrationAdministeringProviderLocation" = Field(None)
    NPI: Union[str, None] = Field(None)
    PhoneNumber: "AdministrationAdministrationAdministeringProviderPhoneNumber" = Field(
        None
    )


class AdministrationAdministrationAdministeringProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class AdministrationAdministrationAdministeringProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class AdministrationAdministrationAdministeringProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class AdministrationAdministrationMedication(RedoxAbstractModel):

    Components: List["AdministrationAdministrationMedicationComponent"] = Field(None)
    Dose: "AdministrationAdministrationMedicationDose" = Field(None)
    Indications: List["AdministrationAdministrationMedicationIndication"] = Field(None)
    LotNumber: Union[str, None] = Field(None)
    Order: "AdministrationAdministrationMedicationOrder" = Field(None)
    Product: "AdministrationAdministrationMedicationProduct" = Field(...)
    Rate: "AdministrationAdministrationMedicationRate" = Field(None)
    Route: "AdministrationAdministrationMedicationRoute" = Field(None)


class AdministrationAdministrationMedicationComponent(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Dose: "AdministrationAdministrationMedicationComponentDose" = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class AdministrationAdministrationMedicationComponentDose(RedoxAbstractModel):

    Quantity: Union[Number, None] = Field(None)
    Units: Union[str, None] = Field(None)


class AdministrationAdministrationMedicationDose(RedoxAbstractModel):

    Quantity: Union[Number, None] = Field(None)
    Units: Union[str, None] = Field(None)


class AdministrationAdministrationMedicationIndication(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


class AdministrationAdministrationMedicationOrder(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)


class AdministrationAdministrationMedicationProduct(RedoxAbstractModel):

    AltCodes: List["AdministrationAdministrationMedicationProductAltCode"] = Field(None)
    Code: str = Field(...)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class AdministrationAdministrationMedicationProductAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class AdministrationAdministrationMedicationRate(RedoxAbstractModel):

    Quantity: Union[Number, None] = Field(None)
    Units: Union[str, None] = Field(None)


class AdministrationAdministrationMedicationRoute(RedoxAbstractModel):

    AltCodes: List["AdministrationAdministrationMedicationRouteAltCode"] = Field(None)
    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class AdministrationAdministrationMedicationRouteAltCode(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    CodeSystem: Union[str, None] = Field(None)
    CodeSystemName: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class AdministrationAdministrationOrderedBy(RedoxAbstractModel):

    Address: "AdministrationAdministrationOrderedByAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "AdministrationAdministrationOrderedByLocation" = Field(None)
    PhoneNumber: "AdministrationAdministrationOrderedByPhoneNumber" = Field(None)


class AdministrationAdministrationOrderedByAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class AdministrationAdministrationOrderedByLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class AdministrationAdministrationOrderedByPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class AdministrationAdministrationVerifiedBy(RedoxAbstractModel):

    Address: "AdministrationAdministrationVerifiedByAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "AdministrationAdministrationVerifiedByLocation" = Field(None)
    PhoneNumber: "AdministrationAdministrationVerifiedByPhoneNumber" = Field(None)


class AdministrationAdministrationVerifiedByAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class AdministrationAdministrationVerifiedByLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class AdministrationAdministrationVerifiedByPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class AdministrationMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["AdministrationMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["AdministrationMetaLog"] = Field(None)
    Message: "AdministrationMetaMessage" = Field(None)
    Source: "AdministrationMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "AdministrationMetaTransmission" = Field(None)


class AdministrationMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class AdministrationMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class AdministrationMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class AdministrationMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class AdministrationMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class AdministrationPatient(RedoxAbstractModel):

    Demographics: "AdministrationPatientDemographics" = Field(None)
    Identifiers: List["AdministrationPatientIdentifier"] = Field(...)
    Notes: List[str] = Field(None)


class AdministrationPatientDemographics(RedoxAbstractModel):

    Address: "AdministrationPatientDemographicsAddress" = Field(None)
    Citizenship: List[str] = Field(None)
    DeathDateTime: Union[str, None] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    IsDeceased: Union[bool, None] = Field(None)
    IsHispanic: Union[bool, None] = Field(None)
    Language: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    MaritalStatus: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "AdministrationPatientDemographicsPhoneNumber" = Field(None)
    Race: Union[str, None] = Field(None)
    Religion: Union[str, None] = Field(None)
    Sex: Union[str, None] = Field(None)
    SSN: Union[str, None] = Field(None)


class AdministrationPatientDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class AdministrationPatientDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class AdministrationPatientIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: str = Field(...)


class AdministrationVisit(RedoxAbstractModel):

    AccountNumber: Union[str, None] = Field(None)
    AttendingProvider: "AdministrationVisitAttendingProvider" = Field(None)
    Location: "AdministrationVisitLocation" = Field(None)
    PatientClass: Union[str, None] = Field(None)
    ReferringProvider: "AdministrationVisitReferringProvider" = Field(None)
    VisitDateTime: Union[str, None] = Field(None)
    VisitNumber: Union[str, None] = Field(None)


class AdministrationVisitAttendingProvider(RedoxAbstractModel):

    Address: "AdministrationVisitAttendingProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "AdministrationVisitAttendingProviderLocation" = Field(None)
    PhoneNumber: "AdministrationVisitAttendingProviderPhoneNumber" = Field(None)


class AdministrationVisitAttendingProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class AdministrationVisitAttendingProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class AdministrationVisitAttendingProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class AdministrationVisitLocation(RedoxAbstractModel):

    Bed: Union[str, None] = Field(None)
    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class AdministrationVisitReferringProvider(RedoxAbstractModel):

    Address: "AdministrationVisitReferringProviderAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "AdministrationVisitReferringProviderLocation" = Field(None)
    PhoneNumber: "AdministrationVisitReferringProviderPhoneNumber" = Field(None)


class AdministrationVisitReferringProviderAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class AdministrationVisitReferringProviderLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class AdministrationVisitReferringProviderPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


Administration.update_forward_refs()
AdministrationAdministration.update_forward_refs()
AdministrationAdministrationAdministeringProvider.update_forward_refs()
AdministrationAdministrationMedication.update_forward_refs()
AdministrationAdministrationMedicationComponent.update_forward_refs()
AdministrationAdministrationMedicationProduct.update_forward_refs()
AdministrationAdministrationMedicationRoute.update_forward_refs()
AdministrationAdministrationOrderedBy.update_forward_refs()
AdministrationAdministrationVerifiedBy.update_forward_refs()
AdministrationMeta.update_forward_refs()
AdministrationPatient.update_forward_refs()
AdministrationPatientDemographics.update_forward_refs()
AdministrationVisit.update_forward_refs()
AdministrationVisitAttendingProvider.update_forward_refs()
AdministrationVisitReferringProvider.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class New(EventTypeAbstractModel):

    Meta: "NewMeta" = Field(...)
    Providers: List["NewProvider"] = Field(...)


class NewMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["NewMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["NewMetaLog"] = Field(None)
    Message: "NewMetaMessage" = Field(None)
    Source: "NewMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "NewMetaTransmission" = Field(None)


class NewMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class NewMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class NewMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class NewMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class NewMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class NewProvider(RedoxAbstractModel):

    Demographics: "NewProviderDemographics" = Field(None)
    Identifiers: List["NewProviderIdentifier"] = Field(...)
    IsActive: bool = Field(...)
    Qualifications: List["NewProviderQualification"] = Field(None)
    Roles: List["NewProviderRole"] = Field(None)


class NewProviderDemographics(RedoxAbstractModel):

    Addresses: List["NewProviderDemographicsAddress"] = Field(None)
    Credentials: List[str] = Field(None)
    DOB: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    Languages: List[str] = Field(None)
    LastName: Union[str, None] = Field(None)
    MiddleName: Union[str, None] = Field(None)
    PhoneNumber: "NewProviderDemographicsPhoneNumber" = Field(None)
    Sex: Union[str, None] = Field(None)


class NewProviderDemographicsAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    Use: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class NewProviderDemographicsPhoneNumber(RedoxAbstractModel):

    Home: Union[str, None] = Field(None)
    Mobile: Union[str, None] = Field(None)
    Office: Union[str, None] = Field(None)


class NewProviderIdentifier(RedoxAbstractModel):

    ID: str = Field(...)
    IDType: Union[str, None] = Field(None)


class NewProviderQualification(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)
    EndDate: Union[str, None] = Field(None)
    Identifiers: List["NewProviderQualificationIdentifier"] = Field(None)
    StartDate: Union[str, None] = Field(None)


class NewProviderQualificationIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class NewProviderRole(RedoxAbstractModel):

    Availability: List["NewProviderRoleAvailability"] = Field(None)
    Identifiers: List["NewProviderRoleIdentifier"] = Field(None)
    Locations: List["NewProviderRoleLocation"] = Field(None)
    Organization: "NewProviderRoleOrganization" = Field(None)
    Services: List["NewProviderRoleService"] = Field(None)
    Specialties: List["NewProviderRoleSpecialty"] = Field(None)


class NewProviderRoleAvailability(RedoxAbstractModel):

    AvailableEndTime: Union[str, None] = Field(None)
    AvailableStartTime: Union[str, None] = Field(None)
    Days: List[str] = Field(None)


class NewProviderRoleIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class NewProviderRoleLocation(RedoxAbstractModel):

    Address: "NewProviderRoleLocationAddress" = Field(None)
    Description: Union[str, None] = Field(None)
    EmailAddresses: List[str] = Field(None)
    Identifiers: List["NewProviderRoleLocationIdentifier"] = Field(None)
    Name: Union[str, None] = Field(None)
    PhoneNumber: "NewProviderRoleLocationPhoneNumber" = Field(None)
    Status: Union[str, None] = Field(None)


class NewProviderRoleLocationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class NewProviderRoleLocationIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class NewProviderRoleLocationPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class NewProviderRoleOrganization(RedoxAbstractModel):

    Address: "NewProviderRoleOrganizationAddress" = Field(None)
    Identifiers: List["NewProviderRoleOrganizationIdentifier"] = Field(None)
    IsActive: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class NewProviderRoleOrganizationAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class NewProviderRoleOrganizationIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class NewProviderRoleService(RedoxAbstractModel):

    Description: Union[str, None] = Field(None)
    Identifiers: List["NewProviderRoleServiceIdentifier"] = Field(None)
    PhoneNumber: "NewProviderRoleServicePhoneNumber" = Field(None)
    Type: Union[str, None] = Field(None)


class NewProviderRoleServiceIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


class NewProviderRoleServicePhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class NewProviderRoleSpecialty(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Description: Union[str, None] = Field(None)


New.update_forward_refs()
NewMeta.update_forward_refs()
NewProvider.update_forward_refs()
NewProviderDemographics.update_forward_refs()
NewProviderQualification.update_forward_refs()
NewProviderRole.update_forward_refs()
NewProviderRoleLocation.update_forward_refs()
NewProviderRoleOrganization.update_forward_refs()
NewProviderRoleService.update_forward_refs()



# -*- coding: utf-8 -*-
# ----  AUTO-GENERATED BY redox_lib_gen. DO NOT MODIFY MANUALLY!!  ---- #

from typing import List, Union

from pydantic import Field

from ..abstract_base import EventTypeAbstractModel, RedoxAbstractModel
from ..field_types import Number


class DocumentQueryResponse(EventTypeAbstractModel):

    Documents: List["DocumentQueryResponseDocument"] = Field(...)
    Meta: "DocumentQueryResponseMeta" = Field(...)
    Patient: "DocumentQueryResponsePatient" = Field(None)


class DocumentQueryResponseDocument(RedoxAbstractModel):

    Author: "DocumentQueryResponseDocumentAuthor" = Field(None)
    DateTime: Union[str, None] = Field(None)
    ID: str = Field(...)
    Locale: Union[str, None] = Field(None)
    Location: "DocumentQueryResponseDocumentLocation" = Field(None)
    Title: Union[str, None] = Field(None)
    Type: "DocumentQueryResponseDocumentType" = Field(None)
    Visit: "DocumentQueryResponseDocumentVisit" = Field(None)


class DocumentQueryResponseDocumentAuthor(RedoxAbstractModel):

    Address: "DocumentQueryResponseDocumentAuthorAddress" = Field(None)
    Credentials: List[str] = Field(None)
    EmailAddresses: List[str] = Field(None)
    FirstName: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)
    LastName: Union[str, None] = Field(None)
    Location: "DocumentQueryResponseDocumentAuthorLocation" = Field(None)
    PhoneNumber: "DocumentQueryResponseDocumentAuthorPhoneNumber" = Field(None)
    Type: Union[str, None] = Field(None)


class DocumentQueryResponseDocumentAuthorAddress(RedoxAbstractModel):

    City: Union[str, None] = Field(None)
    Country: Union[str, None] = Field(None)
    County: Union[str, None] = Field(None)
    State: Union[str, None] = Field(None)
    StreetAddress: Union[str, None] = Field(None)
    ZIP: Union[str, None] = Field(None)


class DocumentQueryResponseDocumentAuthorLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)
    Facility: Union[str, None] = Field(None)
    Room: Union[str, None] = Field(None)
    Type: Union[str, None] = Field(None)


class DocumentQueryResponseDocumentAuthorPhoneNumber(RedoxAbstractModel):

    Office: Union[str, None] = Field(None)


class DocumentQueryResponseDocumentLocation(RedoxAbstractModel):

    Department: Union[str, None] = Field(None)


class DocumentQueryResponseDocumentType(RedoxAbstractModel):

    Code: Union[str, None] = Field(None)
    Codeset: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class DocumentQueryResponseDocumentVisit(RedoxAbstractModel):

    EndDateTime: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)
    StartDateTime: Union[str, None] = Field(None)


class DocumentQueryResponseMeta(RedoxAbstractModel):

    DataModel: str = Field(...)
    Destinations: List["DocumentQueryResponseMetaDestination"] = Field(None)
    EventDateTime: Union[str, None] = Field(None)
    EventType: str = Field(...)
    FacilityCode: Union[str, None] = Field(None)
    Logs: List["DocumentQueryResponseMetaLog"] = Field(None)
    Message: "DocumentQueryResponseMetaMessage" = Field(None)
    Source: "DocumentQueryResponseMetaSource" = Field(None)
    Test: Union[bool, None] = Field(None)
    Transmission: "DocumentQueryResponseMetaTransmission" = Field(None)


class DocumentQueryResponseMetaDestination(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class DocumentQueryResponseMetaLog(RedoxAbstractModel):

    AttemptID: Union[str, None] = Field(None)
    ID: Union[str, None] = Field(None)


class DocumentQueryResponseMetaMessage(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class DocumentQueryResponseMetaSource(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    Name: Union[str, None] = Field(None)


class DocumentQueryResponseMetaTransmission(RedoxAbstractModel):

    ID: Union[Number, None] = Field(None)


class DocumentQueryResponsePatient(RedoxAbstractModel):

    Identifiers: List["DocumentQueryResponsePatientIdentifier"] = Field(None)


class DocumentQueryResponsePatientIdentifier(RedoxAbstractModel):

    ID: Union[str, None] = Field(None)
    IDType: Union[str, None] = Field(None)


DocumentQueryResponse.update_forward_refs()
DocumentQueryResponseDocument.update_forward_refs()
DocumentQueryResponseDocumentAuthor.update_forward_refs()
DocumentQueryResponseMeta.update_forward_refs()
DocumentQueryResponsePatient.update_forward_refs()
